krig_auto_params: Find "best" variogram parameters.

Description Usage Arguments Value Breaks default Author(s) See Also

Description

Find the "best" variogram parameters for a given geodata object. Several different models are tested; the one with the lowest least squares error is chosen.

Usage

1
2
krig_auto_params(geodata, trend = "cte", breaks = krig_breaks(2, 320,
  30))

Arguments

geodata

a list containing element coords as described next. Typically an object of the class "geodata" - a geoR data-set. If not provided the arguments coords must be provided instead.

trend

specifies the mean part of the model. See documentation of trend.spatial for further details. Defaults to "cte".

breaks

a vector with values to define the variogram binning. Only used when option = "bin". See DETAILS below for more details on how to specify the bins.

Value

A list of the best fitted variogram parameters. The following description is adapted from geoR::variog() – which you should see for more details:

Breaks default

The default breaks argument is set to have more points where the exponential curve rises the most and fewer at large distances. This means that the curve fitting is not overly biased by points beyond the effective maximum range.

Author(s)

Graham Zemunik (grah.zem@gmail.com).

See Also

geoR::variog.


forestgeo/fgeo.krig documentation built on June 26, 2019, 8:09 p.m.